@@ -18,3 +18,12 @@ test_that("is.instant/is.timepoint handle vectors",{
   expect_that(is.instant(as.POSIXct(c("2008-08-03 13:01:59", 
   	"2008-08-03 13:01:59"), tz = "UTC")), is_true())
 })
+
+test_that("now() handles time zone input correctly",{
+  expect_identical(floor_date(now("UTC"), "minute"), floor_date(as.POSIXct(format(
+    as.POSIXct(Sys.time()), tz = "UTC"), tz = "UTC"), "minute"))
+})
+
+test_that("today() works correctly",{
+  expect_identical(today(), Sys.Date())
+})
\ No newline at end of file
